@@ -40,7 +40,7 @@ class _Logger(object):
         stdout.
         '''
         self.handlers.append({'minlevel' : minlevel, 'stream' : stream,
-            'newline' : True, 'maxlevel' : maxlevel})
+                              'newline' : True, 'maxlevel' : maxlevel})
 
     def clearhandlers(self):
         '''Clear the list of handlers.
@@ -111,4 +111,8 @@ class _Logger(object):
         '''Log a message with level CRITICAL.'''
         self.log(CRITICAL, msg)
 
+    # aliases
+    warn = warning
+
 Logger = _Logger()
+
